/*
 *
 *      Copyright (c) 2018-2025, avenue All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the pig4cloud.com developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: avenue
 *
 */

package com.bj1890.avenue.admin.mapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bj1890.avenue.admin.api.dto.UserDTO;
import com.bj1890.avenue.admin.api.entity.SysUser;
import com.bj1890.avenue.admin.api.vo.UserVO;
import com.bj1890.avenue.common.data.datascope.DataScope;
import com.bj1890.avenue.common.data.datascope.AvenueBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Set;

/**
 * <p>
 * 用户表 Mapper 接口
 * </p>
 *
 * @author avenue
 * @since 2017-10-29
 */
@Mapper
public interface SysUserMapper extends AvenueBaseMapper<SysUser> {

	/**
	 * 通过用户名查询用户信息（含有角色信息）
	 * @param username 用户名
	 * @return userVo
	 */
	UserVO getUserVoByUsername(String username);

	/**
	 * 分页查询用户信息（含角色）
	 * @param page 分页
	 * @param userDTO 查询参数
	 * @param dataScope
	 * @return list
	 */
	IPage<UserVO> getUserVosPage(Page page, @Param("query") UserDTO userDTO, DataScope dataScope);

	/**
	 * 通过ID查询用户信息
	 * @param id 用户ID
	 * @return userVo
	 */
	UserVO getUserVoById(Long id);

	/**
	 * 查询用户列表
	 * @param userDTO 查询条件
	 * @param dataScope 数据权限声明
	 * @return
	 */
	List<UserVO> selectVoListByScope(@Param("query") UserDTO userDTO, DataScope dataScope);

	/**
	 * 通过部门id查询用户
	 * @param deptId
	 * @return
	 */
    List<UserVO> getListUserByDeptId(String deptId);

	/**
	 * 根据角色code 部门id 查询用户
	 * @param roles
	 * @param deptIds
	 * @return
	 */
	Set<Long> getListUserIdByDeptIdAndRoleCode(@Param("roles") String[] roles,@Param("deptIds") String[] deptIds);
}
